@@ -21,16 +21,18 @@ test_zero(daemons(0L))
 test_error(mirai(), "missing expression, perhaps wrap in {}?")
 test_error(mirai(a, 1), "all `...` arguments must be named")
 test_error(mirai(a, .args = list(1)), "all items in `.args` must be named")
-test_error(mirai_map(1:2, identity), "daemons must be set")
+test_error(mirai_map(1:2, identity))
 test_error(daemons(url = "URL"), "Invalid argument")
 test_error(daemons(-1), "zero or greater")
 test_error(daemons(raw(0L)), "must be numeric")
-test_error(daemons(1, dispatcher = "p"), "should be either TRUE or FALSE")
-test_error(daemons(url = local_url(), dispatcher = "t"), "should be either TRUE or FALSE")
+test_error(daemons(1, dispatcher = 1L), "should be either TRUE or FALSE")
+test_error(daemons(url = local_url(), dispatcher = 0), "should be either TRUE or FALSE")
 test_error(dispatcher(client = "URL"), "must be 1 or greater")
 test_error(daemon("URL"), "Invalid argument")
 test_error(launch_local(1L), "daemons must be set")
 test_true(!daemons_set())
+test_error(require_daemons())
+test_error(mirai:::stop_d(), "No daemons set")
 test_type("character", host_url())
 test_type("character", names(host_url()))
 test_true(all(startsWith(host_url(tls = TRUE), "tls")))
@@ -39,6 +41,7 @@ test_identical(local_url(tcp = TRUE), "tcp://127.0.0.1:0")
 test_true(grepl("5555", local_url(tcp = TRUE, port = 5555), fixed = TRUE))
 test_type("list", ssh_config("ssh://remotehost"))
 test_type("list", ssh_config("ssh://remotehost", tunnel = TRUE))
+test_type("list", cluster_config())
 test_true(is_mirai_interrupt(r <- mirai:::mk_interrupt_error()))
 test_print(r)
 test_true(is_mirai_error(r <- `class<-`("Error in: testing\n", c("miraiError", "errorValue", "try-error"))))
@@ -71,7 +74,7 @@ connection && {
   `lang obj` <- quote(m + n + 2L)
   args <- c(m = 2L, n = 4L)
   m <- mirai(.expr = `lang obj`, .args = args, .timeout = 2000L)
-  if (!is_error_value(call_mirai_(m)$data)) test_equal(m$data, 8L)
+  if (!is_error_value(call_mirai(m)$data)) test_equal(m$data, 8L)
   test_true(!stop_mirai(m))
   Sys.sleep(1L)
   m <- mirai(mirai::on_daemon(), .timeout = 2000L)
@@ -81,6 +84,7 @@ connection && {
   test_print(d)
   test_error(daemons(1L), "daemons already set")
   test_true(daemons_set())
+  test_true(require_daemons())
   me <- mirai(mirai::mirai(), .timeout = 2000L)[]
   if (!is_mirai_error(me)) test_true(is_error_value(me))
   if (is_mirai_error(me)) test_type("list", me$stack.trace)
@@ -107,7 +111,7 @@ connection && {
   test_zero(daemons(0L))
   Sys.sleep(1L)
   test_equal(1L, daemons(1L, dispatcher = FALSE, maxtasks = 10L, walltime = 10000L, idletime = 20000L, cleanup = FALSE, output = TRUE, .compute = "new"))
-  test_type("character", nextget("urls", .compute = "new"))
+  test_type("character", nextget("url", .compute = "new"))
   test_type("integer", nextstream(.compute = "new"))
   Sys.sleep(1.5)
   test_type("list", everywhere({}, as.environment(df), .compute = "new"))
@@ -127,12 +131,12 @@ connection && {
   Sys.sleep(1L)
   test_zero(daemons(url = value <- local_url(), dispatcher = FALSE))
   test_identical(status()$daemons, value)
-  test_identical(nextget("urls"), value)
+  test_identical(nextget("url"), value)
   test_type("character", launch_remote(remote = remote_config(command = "echo", args = list(c("Test out:", ".", ">/dev/null")), rscript = "/usr/lib/R/bin/Rscript")))
   test_error(launch_remote(remote = ssh_config("ssh://127.0.0.1:5456", tunnel = TRUE)), "127.0.0.1")
   test_zero(daemons(0L))
   Sys.sleep(1L)
-  test_zero(daemons(n = 2L, url = value <- "ws://:0", dispatcher = FALSE, remote = remote_config(quote = TRUE)))
+  test_zero(daemons(n = 2L, url = value <- "ws://:0", dispatcher = "none", remote = remote_config(quote = TRUE)))
   test_true(status()$daemons != value)
   test_zero(daemons(0L))
 }
@@ -159,6 +163,7 @@ connection && {
   test_true(all(mirai_map(list(c(a = 1, b = 1, c = 1), 3), sum)[.flat] == 3))
   test_type("language", mirai_map(list(quote(1+2)), identity)[][[1]])
   test_class("Date", mirai_map(data.frame(x = as.Date("2020-01-01")), identity)[][[1]])
+  test_true(is_mirai_error(mirai_map(1:2, function(x) daemons(1))[][[1]]))
   test_zero(daemons(0L))
 }
 # parallel cluster tests
@@ -235,7 +240,7 @@ connection && Sys.getenv("NOT_CRAN") == "true" && {
   test_zero(with(daemons(url = "tcp://:0", correcttype = c(1, 0), token = TRUE), {8L - 9L + 1L}))
   test_zero(daemons(n = 2, "ws://:0"))
   test_type("integer", nextget("pid"))
-  test_equal(length(nextget("urls")), 1L)
+  test_equal(length(nextget("url")), 1L)
   Sys.sleep(1L)
   status <- daemons()
   test_type("list", status)
@@ -250,6 +255,7 @@ connection && Sys.getenv("NOT_CRAN") == "true" && {
   test_type("list", res <- mirai_map(c(1,1), rnorm)[.progress])
   test_true(res[[1L]] != res[[2L]])
   test_equal(2L, daemons()[["connections"]])
+  Sys.sleep(0.5)
   test_zero(daemons(0L))
   Sys.sleep(1L)
   test_zero(daemons(url = "tls+tcp://127.0.0.1:0", dispatcher = TRUE))
@@ -268,12 +274,13 @@ connection && Sys.getenv("NOT_CRAN") == "true" && {
   Sys.sleep(0.5)
   cfg <- serial_config("custom", function(x) serialize(x, NULL), unserialize)
   test_zero(daemons(url = host_url(), pass = "test", serial = cfg))
+  if (.Platform$OS.type == "unix") test_type("character", launch_remote(remote = cluster_config(command = "/bin/sh", options = "#SBATCH", rscript = file.path(R.home("bin"), "Rscript"))))
   test_equal(launch_local(1L), 1L)
   Sys.sleep(1L)
   q <- quote({ list2env(list(b = 2), envir = .GlobalEnv); 0L})
   mm <- everywhere(q)
   test_type("list", mm)
-  test_zero(collect_mirai(mm, ".flat"))
+  test_zero(sum(collect_mirai(mm, ".flat")))
   m <- mirai(b, .timeout = 1000)
   if (!is_error_value(m[])) test_equal(m[], 2L)
   test_zero(daemons(0))
@@ -362,7 +369,7 @@ connection && Sys.getenv("NOT_CRAN") == "true" && {
   test_class("errorValue", mirai(y)[])
   test_identical(s, !logical(10L))
   test_equal(status()$connections, 1L)
-  test_equal(length(nextget("urls")), 1L)
+  test_equal(length(nextget("url")), 1L)
   test_class("miraiLaunchCmd", launch_remote(1))
   test_zero(daemons(0))
 }
